searchData={"items":[{"type":"module","title":"Numero","doc":"Numero cat either normalize non-english digits in strings,\nor convert english digits to non-english digits of your choice.","ref":"Numero.html"},{"type":"function","title":"Numero.digit_only?/1","doc":"Checks if all characters in a given string is numerical (In any utf number bases)","ref":"Numero.html#digit_only?/1"},{"type":"function","title":"Examples - Numero.digit_only?/1","doc":"iex> Numero.digit_only?(\"1234567890\")\n    true\n\n    iex> Numero.digit_only?(\"12 34\")\n    false\n\n    iex> Numero.digit_only?(\"a123\")\n    false\n\n    iex> Numero.digit_only?(\"۱۲۳\") # Persian digits\n    true","ref":"Numero.html#digit_only?/1-examples"},{"type":"function","title":"Numero.normalize/1","doc":"Converts a string number to its standard english format","ref":"Numero.html#normalize/1"},{"type":"function","title":"Examples - Numero.normalize/1","doc":"iex> Numero.normalize(\"1۲3\")\n    \"123\"\n\n    iex> Numero.normalize(\"1۲3.1۱۰\")\n    \"123.110\"\n\n    iex> Numero.normalize(\"1۲a3.1۱۰ hello\")\n    \"12a3.110 hello\"","ref":"Numero.html#normalize/1-examples"},{"type":"function","title":"Numero.normalize_as_number/1","doc":"Converts a string number to number (Integer or Float)\n\nReturns ``:error`` if input string is not in correct format.","ref":"Numero.html#normalize_as_number/1"},{"type":"function","title":"Examples - Numero.normalize_as_number/1","doc":"iex> Numero.normalize_as_number(\"1۲3\")\n    {:ok, 123}\n\n    iex> Numero.normalize_as_number(\"1۲3.1۱۰\")\n    {:ok, 123.11}\n\n    iex> Numero.normalize_as_number(\"1a3.1\")\n    :error","ref":"Numero.html#normalize_as_number/1-examples"},{"type":"function","title":"Numero.normalize_as_number!/1","doc":"Converts a string number to number (Integer or Float)\n\nThrows match error if input string is not in correct format","ref":"Numero.html#normalize_as_number!/1"},{"type":"function","title":"Examples - Numero.normalize_as_number!/1","doc":"iex> Numero.normalize_as_number!(\"1۲3\")\n    123\n\n    iex> Numero.normalize_as_number!(\"1۲3.1۱۰\")\n    123.11","ref":"Numero.html#normalize_as_number!/1-examples"},{"type":"function","title":"Numero.remove_non_digits/2","doc":"Removes non digit chars from a given string","ref":"Numero.html#remove_non_digits/2"},{"type":"function","title":"Parameters - Numero.remove_non_digits/2","doc":"- str: A given string to remove non numerical chars from\n  - exceptions(optional): a list of chars to accept and dont remove. e.g.: ~c[a ]","ref":"Numero.html#remove_non_digits/2-parameters"},{"type":"function","title":"Examples - Numero.remove_non_digits/2","doc":"iex> Numero.remove_non_digits(\"0 1 2 3 4 5 6 7 8 9 abcd\")\n    \"0123456789\"\n\n    iex> Numero.remove_non_digits(\"0 1 2 3 4 5 6 7 8 9 abcd\", ~c[a ])\n    \"0 1 2 3 4 5 6 7 8 9 a\"\n\n    iex> Numero.remove_non_digits(\"\")\n    \"\"\n\n    iex> Numero.remove_non_digits(\"a0b1c2.,asd(*$!@#!@9-=+)\")\n    \"0129\"","ref":"Numero.html#remove_non_digits/2-examples"},{"type":"extras","title":"Numero","doc":"# Numero\n\n[![Build Status](https://github.com/alisinabh/Numero/actions/workflows/ci.yml/badge.svg)](https://github.com/alisinabh/Numero)\n[![Module Version](https://img.shields.io/hexpm/v/numero.svg)](https://hex.pm/packages/numero)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/numero/)\n\n\nA micro library for converting non-english UTF8 digits. (like ۱=1, ۲=2)","ref":"readme.html"},{"type":"extras","title":"Supported languages - Numero","doc":"Almost all numbers defined in Unicode is supported in Numero.\n\nFor more info on supported characters you can visit [here](http://www.fileformat.info/info/unicode/category/Nd/list.htm)","ref":"readme.html#supported-languages"},{"type":"extras","title":"Installation - Numero","doc":"Numero can be installed\nby adding `numero` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:numero, \"~> 0.3.0\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Using Numero - Numero","doc":"On strings for strings:\n\n```elixir\nresult = Numero.normalize(\"1۲۳۰4a۳tس\")\n# result = \"12304a3tس\"\n```\n\nSmart numeric convert:\n\n(Convert numbers to Integer or Float based on input string)\n\n```elixir\nresult = Numero.normalize_as_number(\"1۲۳۰4۳\")\n# result = {:ok, 123043}\n\nresult = Numero.normalize_as_number(\"1۲۳۰4۳.۴5\")\n# result = {:ok, 123043.45}\n\nresult = Numero.normalize_as_number!(\"1۲۳۰4۳.۴5\")\n# result = 123043.45\n```\n\nStrip all non numeric chars from a string:\n\n```elixir\nresult = Numero.remove_non_digits(\"12 345abs\")\n# result = \"12345\"\n\n# Or even make exceptions for some chars like 'a' and ' ' (space)\nresult = Numero.remove_non_digits(\"12 345bas\", ~c[a ])\n# result = \"12 345a\"\n```\n\nChecking if a string is all numbers\n```elixir\nresult = Numero.digit_only?(\"1234567890\")\n# result = true\n\nresult = Numero.digit_only?(\"1234567890.a\")\n# result = false\n```\n\n[https://hexdocs.pm/numero](https://hexdocs.pm/numero).","ref":"readme.html#using-numero"}],"content_type":"text/markdown"}